@@ -17,7 +17,6 @@ from openapi_python_client import utils
 from .config import Config
 from .parser import GeneratorData, import_string_from_class
 from .parser.errors import GeneratorError
-from .utils import snake_case
 
 if sys.version_info.minor < 8:  # version did not exist before 3.8, need to use a backport
     from importlib_metadata import version
@@ -58,6 +57,7 @@ class Project:  # pylint: disable=too-many-instance-attributes
         self.openapi: GeneratorData = openapi
         self.meta: MetaType = meta
         self.file_encoding = file_encoding
+        self.config = config
 
         package_loader = PackageLoader(__package__)
         loader: BaseLoader
@@ -87,6 +87,8 @@ class Project:  # pylint: disable=too-many-instance-attributes
         self.env.filters.update(TEMPLATE_FILTERS)
         self.env.globals.update(
             utils=utils,
+            python_identifier=lambda x: utils.PythonIdentifier(x, config.field_prefix),
+            class_name=lambda x: utils.ClassName(x, config.field_prefix),
             package_name=self.package_name,
             package_dir=self.package_dir,
             package_description=self.package_description,
@@ -267,7 +269,7 @@ class Project:  # pylint: disable=too-many-instance-attributes
             )
 
             for endpoint in collection.endpoints:
-                module_path = tag_dir / f"{snake_case(endpoint.name)}.py"
+                module_path = tag_dir / f"{utils.PythonIdentifier(endpoint.name, self.config.field_prefix)}.py"
                 module_path.write_text(endpoint_template.render(endpoint=endpoint), encoding=self.file_encoding)
 
 
